@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bdatatrackreader.h 471872 2005-10-19 01:04:47Z trueg $
+ * $Id: k3bdatatrackreader.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 
 #include <k3bthreadjob.h>
 #include <k3bmsf.h>
+#include <k3bglobals.h>
 
 namespace K3bDevice {
   class Device;
@@ -45,9 +46,9 @@ class K3bDataTrackReader : public K3bThreadJob
 
   enum SectorSize {
     AUTO = 0,
-    MODE1 = 2048,
-    MODE2FORM1 = 2056,
-    MODE2FORM2 = 2332
+    MODE1 = K3b::SECTORSIZE_DATA_2048,
+    MODE2FORM1 = K3b::SECTORSIZE_DATA_2048_SUBHEADER,
+    MODE2FORM2 = K3b::SECTORSIZE_DATA_2324_SUBHEADER
   };
 
   void setSectorSize( SectorSize size );
