@@ -1,10 +1,10 @@
 /*
  *
- * $Id: k3bisoimager.h 486910 2005-12-09 09:37:17Z trueg $
+ * $Id: k3bisoimager.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,16 +45,37 @@ class K3bIsoImager : public K3bJob, public K3bMkisofsHandler
 
   int size() const { return m_mkisofsPrintSizeResult; }
 
+  virtual bool hasBeenCanceled() const; 
+
   /**
-   * The dummy dir is used to create dirs on the iso-filesystem.
-   *
-   * @return an empty dummy dir for use with K3bDirItems.
+   * Get the checksum calculated during the creation of the image.
    */
-  QString dummyDir( K3bDirItem* );
+  QCString checksum() const;
 
  public slots:
+  /**
+   * Starts the actual image creation. Always run init() 
+   * before starting the image creation
+   */
   virtual void start();
   virtual void cancel();
+
+  /**
+   * Initialize the image creator. This calculates the image size and performs
+   * some checks on the project.
+   *
+   * The initialization process also finishes with the finished() signal just
+   * like a normal job operation. Get the calculated image size via size()
+   */
+  virtual void init();
+
+  /**
+   * Only calculates the size of the image without the additional checks in
+   * init()
+   *
+   * Use this if you need to recalculate the image size for example if the
+   * multisession info changed.
+   */
   virtual void calculateSize();
 
   /**
@@ -76,9 +97,6 @@ class K3bIsoImager : public K3bJob, public K3bMkisofsHandler
   K3bDevice::Device* device() const { return m_device; }
   K3bDataDoc* doc() const { return m_doc; }
 
- signals:
-  void sizeCalculated( int exitCode, int size );
-
  protected:
   virtual void handleMkisofsProgress( int );
   virtual void handleMkisofsInfoMessage( const QString&, int );
@@ -90,8 +108,15 @@ class K3bIsoImager : public K3bJob, public K3bMkisofsHandler
    */
   bool prepareMkisofsFiles();
 
+  /**
+   * The dummy dir is used to create dirs on the iso-filesystem.
+   *
+   * @return an empty dummy dir for use with K3bDirItems.
+   */
+  QString dummyDir( K3bDirItem* );
+
   void outputData();
-  void init();
+  void initVariables();
   virtual void cleanup();
   void clearDummyDirs();
 
@@ -124,10 +149,13 @@ class K3bIsoImager : public K3bJob, public K3bMkisofsHandler
 
  private slots:
   void slotCollectMkisofsPrintSizeStderr(KProcess*, char*, int);
-  void slotCollectMkisofsPrintSizeStdout(KProcess*, char*, int);
+  void slotCollectMkisofsPrintSizeStdout( const QString& );
   void slotMkisofsPrintSizeFinished();
+  void slotDataPreparationDone( bool success );
 
  private:
+  void startSizeCalculation();
+
   class Private;
   Private* d;
 
