@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bisooptions.cpp 489631 2005-12-19 10:58:06Z trueg $
- * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
+ * $Id: k3bisooptions.cpp 639665 2007-03-05 16:29:52Z trueg $
+ * Copyright (C) 2003-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 
 K3bIsoOptions::K3bIsoOptions()
   : m_volumeID( "K3b data project" ),
-    m_applicationID( QString("K3B THE CD KREATOR (C) 1998-2005 SEBASTIAN TRUEG AND THE K3B TEAM") ),
+    m_applicationID( QString("K3B THE CD KREATOR (C) 1998-2006 SEBASTIAN TRUEG AND THE K3B TEAM") ),
     m_systemId( K3b::systemName().upper() ),
     m_inputCharset( "iso8859-1" ),
     m_whiteSpaceTreatmentReplaceString( "_" )
@@ -48,7 +48,9 @@ K3bIsoOptions::K3bIsoOptions()
   m_followSymbolicLinks = false;
   m_createTRANS_TBL = false;
   m_hideTRANS_TBL = false;
-  m_jolietLong = false;
+  m_jolietLong = true;
+
+  m_doNotCacheInodes = true;
 
   m_isoLevel = 2;
 
@@ -64,16 +66,21 @@ K3bIsoOptions::K3bIsoOptions()
 }
 
 
-void K3bIsoOptions::save( KConfigBase* c )
+void K3bIsoOptions::save( KConfigBase* c, bool saveVolumeDesc )
 {
-  c->writeEntry( "volume id", m_volumeID );
-  c->writeEntry( "application id", m_applicationID );
-  c->writeEntry( "preparer", m_preparer );
-  c->writeEntry( "publisher", m_publisher );
-  c->writeEntry( "system id", m_systemId );
-  c->writeEntry( "volume set id", m_volumeSetId );
-  c->writeEntry( "volume set size", m_volumeSetSize );
-  c->writeEntry( "volume set number", m_volumeSetNumber );
+  if( saveVolumeDesc ) {
+    c->writeEntry( "volume id", m_volumeID );
+    c->writeEntry( "application id", m_applicationID );
+    c->writeEntry( "preparer", m_preparer );
+    c->writeEntry( "publisher", m_publisher );
+    c->writeEntry( "system id", m_systemId );
+    c->writeEntry( "volume set id", m_volumeSetId );
+    c->writeEntry( "volume set size", m_volumeSetSize );
+    c->writeEntry( "volume set number", m_volumeSetNumber );
+    c->writeEntry( "abstract file", m_abstractFile );
+    c->writeEntry( "copyright file", m_copyrightFile );
+    c->writeEntry( "bibliograph file", m_bibliographFile );
+  }
 
   c->writeEntry( "rock_ridge", m_createRockRidge );
   c->writeEntry( "joliet", m_createJoliet );
@@ -92,15 +99,17 @@ void K3bIsoOptions::save( KConfigBase* c )
   c->writeEntry( "omit version numbers", m_ISOomitVersionNumbers );
   c->writeEntry( "omit trailing period", m_ISOomitTrailingPeriod );
   c->writeEntry( "no iSO translation", m_ISOnoIsoTranslate );
-  c->writeEntry( "allow multible dots", m_ISOallowMultiDot );
+  c->writeEntry( "allow multiple dots", m_ISOallowMultiDot );
   c->writeEntry( "allow lowercase filenames", m_ISOallowLowercase );
-  c->writeEntry( "follow symbolic links", m_followSymbolicLinks );
+  //  c->writeEntry( "follow symbolic links", m_followSymbolicLinks );
 
   c->writeEntry( "joliet long", m_jolietLong );
 
   c->writeEntry( "force input charset", m_bForceInputCharset );
   c->writeEntry( "input charset", m_inputCharset );
 
+  c->writeEntry( "do not cache inodes", m_doNotCacheInodes );
+
   // save whitespace-treatment
   switch( m_whiteSpaceTreatment ) {
   case strip:
@@ -125,18 +134,23 @@ void K3bIsoOptions::save( KConfigBase* c )
 }
 
 
-K3bIsoOptions K3bIsoOptions::load( KConfigBase* c )
+K3bIsoOptions K3bIsoOptions::load( KConfigBase* c, bool loadVolumeDesc )
 {
   K3bIsoOptions options;
 
-  options.setVolumeID( c->readEntry( "volume id", options.volumeID() ) );
-  options.setApplicationID( c->readEntry( "application id", options.applicationID() ) );
-  options.setPreparer( c->readEntry( "preparer", options.preparer() ) );
-  options.setPublisher( c->readEntry( "publisher", options.publisher() ) );
-  options.setSystemId( c->readEntry( "system id", options.systemId() ) );
-  options.setVolumeSetId( c->readEntry( "volume set id", options.volumeSetId() ) );
-  options.setVolumeSetSize( c->readNumEntry( "volume set size", options.volumeSetSize() ) );
-  options.setVolumeSetNumber( c->readNumEntry( "volume set number", options.volumeSetNumber() ) );
+  if( loadVolumeDesc ) {
+    options.setVolumeID( c->readEntry( "volume id", options.volumeID() ) );
+    options.setApplicationID( c->readEntry( "application id", options.applicationID() ) );
+    options.setPreparer( c->readEntry( "preparer", options.preparer() ) );
+    options.setPublisher( c->readEntry( "publisher", options.publisher() ) );
+    options.setSystemId( c->readEntry( "system id", options.systemId() ) );
+    options.setVolumeSetId( c->readEntry( "volume set id", options.volumeSetId() ) );
+    options.setVolumeSetSize( c->readNumEntry( "volume set size", options.volumeSetSize() ) );
+    options.setVolumeSetNumber( c->readNumEntry( "volume set number", options.volumeSetNumber() ) );
+    options.setAbstractFile( c->readEntry( "abstract file", options.abstractFile() ) );
+    options.setCoprightFile( c->readEntry( "copyright file", options.copyrightFile() ) );
+    options.setBibliographFile( c->readEntry( "bibliograph file", options.bibliographFile() ) );
+  }
 
   options.setForceInputCharset( c->readBoolEntry( "force input charset", options.forceInputCharset() ) );
   if( options.forceInputCharset() )
@@ -164,14 +178,16 @@ K3bIsoOptions K3bIsoOptions::load( KConfigBase* c )
   options.setISOrelaxedFilenames( c->readBoolEntry( "relaxed filenames", options.m_ISOrelaxedFilenames ) );
   options.setISOomitVersionNumbers( c->readBoolEntry( "omit version numbers", options.m_ISOomitVersionNumbers ) );
   options.setISOnoIsoTranslate( c->readBoolEntry( "no iSO translation", options.m_ISOnoIsoTranslate ) );
-  options.setISOallowMultiDot( c->readBoolEntry( "allow multible dots", options.m_ISOallowMultiDot ) );
+  options.setISOallowMultiDot( c->readBoolEntry( "allow multiple dots", options.m_ISOallowMultiDot ) );
   options.setISOallowLowercase( c->readBoolEntry( "allow lowercase filenames", options.m_ISOallowLowercase ) );
   options.setISOomitTrailingPeriod( c->readBoolEntry( "omit trailing period", options.m_ISOomitTrailingPeriod ) );
 
-  options.setFollowSymbolicLinks( c->readBoolEntry( "follow symbolic links", options.followSymbolicLinks() ) );
+  //  options.setFollowSymbolicLinks( c->readBoolEntry( "follow symbolic links", options.m_followSymbolicLinks ) );
 
   options.setJolietLong( c->readBoolEntry( "joliet long", options.jolietLong() ) );
 
+  options.setDoNotCacheInodes( c->readBoolEntry( "do not cache inodes", options.doNotCacheInodes() ) );
+
   QString w = c->readEntry( "white_space_treatment", "noChange" );
   if( w == "replace" )
     options.setWhiteSpaceTreatment( replace );
