@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bmkisofshandler.cpp 487637 2005-12-11 12:04:55Z trueg $
+ * $Id: k3bmkisofshandler.cpp 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2005 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2005 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,6 +16,7 @@
 #include "k3bmkisofshandler.h"
 
 #include <k3bexternalbinmanager.h>
+#include <k3bcore.h>
 #include <k3bjob.h>
 
 #include <kdebug.h>
@@ -53,15 +54,29 @@ bool K3bMkisofsHandler::mkisofsReadError() const
 }
 
 
-void K3bMkisofsHandler::initMkisofs( const K3bExternalBin* bin )
+const K3bExternalBin* K3bMkisofsHandler::initMkisofs()
 {
-  d->mkisofsBin = bin;
-  d->firstProgressValue = -1;
-  d->readError = false;
+  d->mkisofsBin = k3bcore->externalBinManager()->binObject( "mkisofs" );
+
+  if( d->mkisofsBin ) {
+    if( !d->mkisofsBin->copyright.isEmpty() )
+      handleMkisofsInfoMessage( i18n("Using %1 %2 - Copyright (C) %3")
+				.arg("mkisofs").arg(d->mkisofsBin->version).arg(d->mkisofsBin->copyright), 
+				K3bJob::INFO );
+
+    d->firstProgressValue = -1;
+    d->readError = false;
+  }
+  else {
+    kdDebug() << "(K3bMkisofsHandler) could not find mkisofs executable" << endl;
+    handleMkisofsInfoMessage( i18n("Mkisofs executable not found."), K3bJob::ERROR );
+  }
+
+  return d->mkisofsBin;
 }
 
 
-void K3bMkisofsHandler::handleMkisofsOutput( const QString& line )
+void K3bMkisofsHandler::parseMkisofsOutput( const QString& line )
 {
   if( !line.isEmpty() ) {
     if( line.startsWith( d->mkisofsBin->path ) ) {
@@ -72,6 +87,11 @@ void K3bMkisofsHandler::handleMkisofsOutput( const QString& line )
 				  K3bJob::ERROR );
 	d->readError = true;
       }
+      else if( errorLine.startsWith( "Value too large for defined data type" ) ) {
+	handleMkisofsInfoMessage( i18n("Used version of mkisofs does not have large file support."), K3bJob::ERROR );
+	handleMkisofsInfoMessage( i18n("Files bigger than 2 GB cannot be handled."), K3bJob::ERROR );
+	d->readError = true;
+      }
     }
     else if( line.contains( "done, estimate" ) ) {
       int p = parseMkisofsProgress( line );
@@ -88,6 +108,15 @@ void K3bMkisofsHandler::handleMkisofsOutput( const QString& line )
       handleMkisofsInfoMessage( i18n("You may use convmv (http://j3e.de/linux/convmv/) to fix the filename encoding."), K3bJob::ERROR );
       d->readError = true;
     }
+    else if( line.endsWith( "has not an allowable size." ) ) {
+      handleMkisofsInfoMessage( i18n("The boot image has an invalid size."), K3bJob::ERROR );      
+      d->readError = true;
+    }
+    else if( line.endsWith( "has multiple partitions." ) ) {
+      handleMkisofsInfoMessage( i18n("The boot image contains multiple partitions.."), K3bJob::ERROR );
+      handleMkisofsInfoMessage( i18n("A hard-disk boot image has to contain a single partition."), K3bJob::ERROR );
+      d->readError = true;
+    }
     else {
       kdDebug() << "(mkisofs) " << line << endl;
     }
