@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bgrowisofshandler.h 510757 2006-02-17 23:13:49Z trueg $
+ * $Id: k3bgrowisofshandler.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,14 +42,16 @@ class K3bGrowisofsHandler : public QObject
     ERROR_MEDIA,
     ERROR_OVERSIZE,
     ERROR_SPEED_SET_FAILED,
-    ERROR_OPC
+    ERROR_OPC,
+    ERROR_MEMLOCK,
+    ERROR_WRITE_FAILED
   };
 
   int error() const { return m_error; }
 
  public slots:
   /**
-   * This will basicly reset the error type
+   * This will basically reset the error type
    * @param dao was growisofs called with DAO?
    */
   void reset( K3bDevice::Device* = 0, bool dao = false );
