@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bgrowisofswriter.cpp 679276 2007-06-23 13:25:21Z trueg $
+ * $Id: k3bgrowisofswriter.cpp 731898 2007-11-02 08:22:18Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -276,7 +276,10 @@ bool K3bGrowisofsWriter::prepareProcess()
   // because the only thing it does is creating problems.
   // Normally this should be done in growisofs
   //
-  if( dvdCompat && burnDevice()->mediaType() != K3bDevice::MEDIA_DVD_PLUS_RW )
+  int mediaType = burnDevice()->mediaType();
+  if( dvdCompat &&
+      mediaType != K3bDevice::MEDIA_DVD_PLUS_RW &&
+      mediaType != K3bDevice::MEDIA_DVD_RW_OVWR )
     *d->process << "-dvd-compat";
 
   //
@@ -315,7 +318,7 @@ bool K3bGrowisofsWriter::prepareProcess()
   for( QStringList::const_iterator it = params.begin(); it != params.end(); ++it )
     *d->process << *it;
 
-  emit debuggingOutput( "Burned media", K3bDevice::mediaTypeString(burnDevice()->mediaType()) );
+  emit debuggingOutput( "Burned media", K3bDevice::mediaTypeString(mediaType) );
 
   return true;
 }
@@ -547,7 +550,8 @@ void K3bGrowisofsWriter::slotProcessExited( KProcess* p )
 
     int s = d->speedEst->average();
     if( s > 0 )
-      emit infoMessage( i18n("Average overall write speed: %1 KB/s (%2x)").arg(s).arg(KGlobal::locale()->formatNumber((double)s/1385.0), 2), INFO );
+      emit infoMessage( i18n("Average overall write speed: %1 KB/s (%2x)")
+                        .arg(s).arg(KGlobal::locale()->formatNumber((double)s/1385.0), 2), INFO );
 
     if( simulate() )
       emit infoMessage( i18n("Simulation successfully completed"), K3bJob::SUCCESS );
