@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3blistview.cpp 489631 2005-12-19 10:58:06Z trueg $
+ * $Id: k3blistview.cpp 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,6 +39,8 @@
 #include <qprogressbar.h>
 #include <qimage.h>
 
+#include <kpixmapeffect.h>
+
 #include <limits.h>
 
 
@@ -57,7 +59,8 @@ public:
     : showProgress(false),
       progressValue(0),
       totalProgressSteps(100),
-      margin(0) {
+      margin(0),
+      validator(0) {
     editorType = NONE;
     button = false;
     comboEditable = false;
@@ -88,6 +91,8 @@ public:
   int progressValue;
   int totalProgressSteps;
   int margin;
+
+  QValidator* validator;
 };
 
 
@@ -118,10 +123,10 @@ K3bListViewItem::K3bListViewItem(QListViewItem *parent, QListViewItem *after)
 
 
 K3bListViewItem::K3bListViewItem(QListView *parent,
-				 QString s1, QString s2,
-				 QString s3, QString s4,
-				 QString s5, QString s6,
-				 QString s7, QString s8)
+				 const QString& s1, const QString& s2,
+				 const QString& s3, const QString& s4,
+				 const QString& s5, const QString& s6,
+				 const QString& s7, const QString& s8)
   : KListViewItem( parent, s1, s2, s3, s4, s5, s6, s7, s8 )
 { 
   init();
@@ -129,10 +134,10 @@ K3bListViewItem::K3bListViewItem(QListView *parent,
 
 
 K3bListViewItem::K3bListViewItem(QListViewItem *parent,
-				 QString s1, QString s2,
-				 QString s3, QString s4,
-				 QString s5, QString s6,
-				 QString s7, QString s8)
+				 const QString& s1, const QString& s2,
+				 const QString& s3, const QString& s4,
+				 const QString& s5, const QString& s6,
+				 const QString& s7, const QString& s8)
   : KListViewItem( parent, s1, s2, s3, s4, s5, s6, s7, s8 )
 { 
   init();
@@ -140,10 +145,10 @@ K3bListViewItem::K3bListViewItem(QListViewItem *parent,
 
 
 K3bListViewItem::K3bListViewItem(QListView *parent, QListViewItem *after,
-				 QString s1, QString s2,
-				 QString s3, QString s4,
-				 QString s5, QString s6,
-				 QString s7, QString s8)
+				 const QString& s1, const QString& s2,
+				 const QString& s3, const QString& s4,
+				 const QString& s5, const QString& s6,
+				 const QString& s7, const QString& s8)
   : KListViewItem( parent, after, s1, s2, s3, s4, s5, s6, s7, s8 )
 { 
   init();
@@ -151,10 +156,10 @@ K3bListViewItem::K3bListViewItem(QListView *parent, QListViewItem *after,
 
 
 K3bListViewItem::K3bListViewItem(QListViewItem *parent, QListViewItem *after,
-				 QString s1, QString s2,
-				 QString s3, QString s4,
-				 QString s5, QString s6,
-				 QString s7, QString s8)
+				 const QString& s1, const QString& s2,
+				 const QString& s3, const QString& s4,
+				 const QString& s5, const QString& s6,
+				 const QString& s7, const QString& s8)
   : KListViewItem( parent, after, s1, s2, s3, s4, s5, s6, s7, s8 )
 { 
   init();
@@ -195,6 +200,18 @@ void K3bListViewItem::setEditor( int column, int editor, const QStringList& cs )
 }
 
 
+void K3bListViewItem::setValidator( int column, QValidator* v )
+{
+  getColumnInfo(column)->validator = v;
+}
+
+
+QValidator* K3bListViewItem::validator( int col ) const
+{
+  return getColumnInfo(col)->validator;
+}
+
+
 void K3bListViewItem::setButton( int column, bool on )
 {
   ColumnInfo* colInfo = getColumnInfo(column);
@@ -312,6 +329,18 @@ void K3bListViewItem::setMarginVertical( int margin )
 }
 
 
+int K3bListViewItem::marginHorizontal( int col ) const
+{
+  return getColumnInfo( col )->margin;
+}
+
+
+int K3bListViewItem::marginVertical() const
+{
+  return m_vMargin;
+}
+
+
 void K3bListViewItem::setup()
 {
   KListViewItem::setup();
@@ -335,37 +364,43 @@ void K3bListViewItem::paintCell( QPainter* p, const QColorGroup& cg, int col, in
   if( info->backgroundColorSet )
     cgh.setColor( QColorGroup::Base, info->backgroundColor );
 
-  // the margin (we can only translate horizontally since height() is used for painting)
+  // in case this is the selected row has a margin we need to repaint the selection bar
+  if( isSelected() &&
+      (col == 0 || listView()->allColumnsShowFocus()) &&
+      info->margin > 0 ) {
+    
+    p->fillRect( 0, 0, info->margin, height(),
+		 cgh.brush( QColorGroup::Highlight ) );
+    p->fillRect( width-info->margin, 0, info->margin, height(),
+		 cgh.brush( QColorGroup::Highlight ) );
+  }
+  else { // in case we use the KListView alternate color stuff
+    p->fillRect( 0, 0, info->margin, height(),
+		 cgh.brush( QColorGroup::Base ) );
+    p->fillRect( width-info->margin, 0, info->margin, height(),
+		 cgh.brush( QColorGroup::Base ) );
+  }
+
+  // FIXME: the margin (we can only translate horizontally since height() is used for painting)
   p->translate( info->margin, 0 );
 
   if( info->showProgress ) {
     paintProgressBar( p, cgh, col, width-2*info->margin );
   }
   else {
-    KListViewItem::paintCell( p, cgh, col, width-2*info->margin, align );
-
-    // in case this is the selected row has a margin we need to repaint the selection bar
-    if( isSelected() &&
-	(col == 0 || listView()->allColumnsShowFocus()) &&
-	info->margin > 0 ) {
-
-      p->fillRect( -1*info->margin, 0, 0, height(),
-		   cg.brush( QColorGroup::Highlight ) );
-      p->fillRect( width, 0, width+info->margin, height(),
-		   cg.brush( QColorGroup::Highlight ) );
-    }
-    else { // in case we use the KListView alternate color stuff
-      p->fillRect( -1*info->margin, 0, 0, height(),
-		   cg.brush( QColorGroup::Base ) );
-      p->fillRect( width, 0, width+info->margin, height(),
-		   cg.brush( QColorGroup::Base ) );
-    }
+    paintK3bCell( p, cgh, col, width-2*info->margin, align );
   }
 
   p->restore();
 }
 
 
+void K3bListViewItem::paintK3bCell( QPainter* p, const QColorGroup& cg, int col, int width, int align )
+{
+  QListViewItem::paintCell( p, cg, col, width, align );
+}
+
+
 void K3bListViewItem::paintProgressBar( QPainter* p, const QColorGroup& cgh, int col, int width )
 {
   ColumnInfo* info = getColumnInfo( col );
@@ -376,7 +411,7 @@ void K3bListViewItem::paintProgressBar( QPainter* p, const QColorGroup& cgh, int
   if( listView()->hasFocus() )
     flags |= QStyle::Style_HasFocus;
 
-  // the QPainter is translated so 0, m_vMargin is the upper left of our paint rect
+  // FIXME: the QPainter is translated so 0, m_vMargin is the upper left of our paint rect
   QRect r( 0, m_vMargin, width, height()-2*m_vMargin );
 
   // create the double buffer pixmap
@@ -424,6 +459,8 @@ void K3bListViewItem::paintProgressBar( QPainter* p, const QColorGroup& cgh, int
 
 
 
+
+
 K3bCheckListViewItem::K3bCheckListViewItem(QListView *parent)
   : K3bListViewItem( parent ),
     m_checked(false)
@@ -465,13 +502,13 @@ void K3bCheckListViewItem::setChecked( bool checked )
 }
 
 
-void K3bCheckListViewItem::paintCell( QPainter* p, const QColorGroup& cg, int col, int width, int align )
+void K3bCheckListViewItem::paintK3bCell( QPainter* p, const QColorGroup& cg, int col, int width, int align )
 {
-  K3bListViewItem::paintCell( p, cg, col, width, align );
+  K3bListViewItem::paintK3bCell( p, cg, col, width, align );
 
   if( col == 0 ) {
     if( m_checked ) {
-      QRect r( 0, 0, height(), height() );
+      QRect r( 0, marginVertical(), width, /*listView()->style().pixelMetric( QStyle::PM_CheckListButtonSize )*/height()-2*marginVertical() );
 
       QStyle::SFlags flags = QStyle::Style_Default;
       if( listView()->isEnabled() )
@@ -491,6 +528,8 @@ void K3bCheckListViewItem::paintCell( QPainter* p, const QColorGroup& cg, int co
 
 
 
+
+
 // ///////////////////////////////////////////////
 //
 // K3BLISTVIEW
@@ -498,15 +537,23 @@ void K3bCheckListViewItem::paintCell( QPainter* p, const QColorGroup& cg, int co
 // ///////////////////////////////////////////////
 
 
+class K3bListView::Private
+{
+public:
+  QLineEdit* spinBoxLineEdit;
+  QLineEdit* msfEditLineEdit;
+};
+
+
 K3bListView::K3bListView( QWidget* parent, const char* name )
   : KListView( parent, name ),
     m_noItemVMargin( 20 ),
     m_noItemHMargin( 20 )
 {
+  d = new Private;
+
   connect( header(), SIGNAL( sizeChange( int, int, int ) ),
 	   this, SLOT( updateEditorSize() ) );
-  connect( this, SIGNAL(clicked(QListViewItem*, const QPoint&, int)),
-	   this, SLOT(slotClicked(QListViewItem*, const QPoint&, int)) );
 
   m_editorButton = 0;
   m_editorComboBox = 0;
@@ -517,17 +564,28 @@ K3bListView::K3bListView( QWidget* parent, const char* name )
   m_currentEditColumn = 0;
   m_doubleClickForEdit = true;
   m_lastClickedItem = 0;
-  m_validator = 0;
 }
 
 K3bListView::~K3bListView()
 {
-  // FIXME: is this really necessary or does viewport() delete them?
-  delete m_editorButton;
-  delete m_editorComboBox;
-  delete m_editorSpinBox;
-  delete m_editorLineEdit;
-  delete m_editorMsfEdit;
+  delete d;
+}
+
+
+QWidget* K3bListView::editor( K3bListViewItem::EditorType t ) const
+{
+  switch( t ) {
+  case K3bListViewItem::COMBO:
+    return m_editorComboBox;
+  case K3bListViewItem::LINE:
+    return m_editorLineEdit;
+  case K3bListViewItem::SPIN:
+    return m_editorSpinBox;
+  case K3bListViewItem::MSF:
+    return m_editorMsfEdit;
+  default:
+    return 0;
+  }
 }
 
 
@@ -538,24 +596,6 @@ void K3bListView::clear()
 }
 
 
-void K3bListView::slotClicked( QListViewItem* item, const QPoint&, int col )
-{
-  if( item != m_currentEditItem ) {
-    doRename();
-    if( K3bListViewItem* k3bItem = dynamic_cast<K3bListViewItem*>(item) ) {
-      if( item->isEnabled() && (m_lastClickedItem == item || !m_doubleClickForEdit) )
-	showEditor( k3bItem, col );
-      else
-	hideEditor();
-    }
-    else
-      hideEditor();
-    
-    m_lastClickedItem = item;
-  }
-}
-
-
 void K3bListView::editItem( K3bListViewItem* item, int col )
 {
   if( item == 0 )
@@ -602,10 +642,12 @@ void K3bListView::showEditor( K3bListViewItem* item, int col )
   case K3bListViewItem::COMBO:
     m_editorComboBox->show();
     m_editorComboBox->setFocus();
+    m_editorComboBox->setValidator( item->validator(col) );
     break;
   case K3bListViewItem::LINE:
     m_editorLineEdit->show();
     m_editorLineEdit->setFocus();
+    m_editorLineEdit->setValidator( item->validator(col) );
     break;
   case K3bListViewItem::SPIN:
     m_editorSpinBox->show();
@@ -623,11 +665,8 @@ void K3bListView::showEditor( K3bListViewItem* item, int col )
 
 void K3bListView::placeEditor( K3bListViewItem* item, int col )
 {
+  ensureItemVisible( item );
   QRect r = itemRect( item );
-  if ( !r.size().isValid() ) {
-    ensureItemVisible( item );
-    r = itemRect( item );
-  }
 
   r.setX( contentsToViewport( QPoint(header()->sectionPos( col ), 0) ).x() );
   r.setWidth( header()->sectionSize( col ) - 1 );
@@ -687,8 +726,6 @@ QWidget* K3bListView::prepareEditor( K3bListViewItem* item, int col )
       m_editorComboBox = new QComboBox( viewport() );
       connect( m_editorComboBox, SIGNAL(activated(const QString&)), 
 	       this, SLOT(slotEditorComboBoxActivated(const QString&)) );
-      if( m_validator )
-	m_editorComboBox->setValidator( m_validator );
       m_editorComboBox->installEventFilter( this );
     }
     m_editorComboBox->clear();
@@ -703,25 +740,40 @@ QWidget* K3bListView::prepareEditor( K3bListViewItem* item, int col )
     }
     return m_editorComboBox;
 
-  case K3bListViewItem::LINE:
+  case K3bListViewItem::LINE: {
     if( !m_editorLineEdit ) {
       m_editorLineEdit = new QLineEdit( viewport() );
       m_editorLineEdit->setFrameStyle( QFrame::Box | QFrame::Plain );
       m_editorLineEdit->setLineWidth(1);
-      if( m_validator )
-	m_editorLineEdit->setValidator( m_validator );
       m_editorLineEdit->installEventFilter( this );
     }
 
-    m_editorLineEdit->setText( item->text( col ) );
+    QString txt = item->text( col );
+    m_editorLineEdit->setText( txt );
+
+    // select the edit text (handle extensions while doing so)
+    int pos = txt.findRev( '.' );
+    if( pos > 0 )
+      m_editorLineEdit->setSelection( 0, pos );
+    else
+      m_editorLineEdit->setSelection( 0, txt.length() );
+
     return m_editorLineEdit;
+  }
+
+  //
+  // A QSpinBox (and thus also a K3bMsfEdit) uses a QLineEdit), thus
+  // we have to use this QLineEdit as the actual object to dead with
+  //
 
   case K3bListViewItem::SPIN:
     if( !m_editorSpinBox ) {
       m_editorSpinBox = new QSpinBox( viewport() );
+      d->spinBoxLineEdit = static_cast<QLineEdit*>( m_editorSpinBox->child( 0, "QLineEdit" ) );
       connect( m_editorSpinBox, SIGNAL(valueChanged(int)),
 	       this, SLOT(slotEditorSpinBoxValueChanged(int)) );
-      m_editorSpinBox->installEventFilter( this );
+      //      m_editorSpinBox->installEventFilter( this );
+      d->spinBoxLineEdit->installEventFilter( this );
     }
     // set the range
     m_editorSpinBox->setValue( item->text(col).toInt() );
@@ -730,11 +782,11 @@ QWidget* K3bListView::prepareEditor( K3bListViewItem* item, int col )
   case K3bListViewItem::MSF:
     if( !m_editorMsfEdit ) {
       m_editorMsfEdit = new K3bMsfEdit( viewport() );
-//       m_editorMsfEdit->setFrameStyle( QFrame::Box | QFrame::Plain );
-//       m_editorMsfEdit->setLineWidth(1);
+      d->msfEditLineEdit = static_cast<QLineEdit*>( m_editorMsfEdit->child( 0, "QLineEdit" ) );
       connect( m_editorMsfEdit, SIGNAL(valueChanged(int)),
 	       this, SLOT(slotEditorMsfEditValueChanged(int)) );
-      m_editorMsfEdit->installEventFilter( this );
+      //      m_editorMsfEdit->installEventFilter( this );
+      d->msfEditLineEdit->installEventFilter( this );
     }
     m_editorMsfEdit->setText( item->text(col) );
     return m_editorMsfEdit;
@@ -749,20 +801,11 @@ void K3bListView::setCurrentItem( QListViewItem* i )
   if( !i || i == currentItem() )
     return;
 
-//   if( m_currentEditItem )
-//     if( m_currentEditItem->editorType(m_currentEditColumn) == K3bListViewItem::LINE ) {
-//       if( m_editorLineEdit->validator() ) {
-// 	QString str = m_editorLineEdit->text();
-// 	int pos = 0;
-// 	if( m_editorLineEdit->validator()->validate( str, pos ) == QValidator::Acceptable )
-// 	  slotEditorLineEditReturnPressed();
-//       }
-//       else
-// 	slotEditorLineEditReturnPressed();
-//     }
-  doRename();
-  hideEditor();
-  m_currentEditItem = 0;
+  // I cannot remember why I did this here exactly. However, it resets the
+  // m_lastClickedItem and thus invalidates the editing.
+//   doRename();
+//   hideEditor();
+//   m_currentEditItem = 0;
   KListView::setCurrentItem( i );
 }
 
@@ -793,7 +836,8 @@ void K3bListView::drawContentsOffset( QPainter * p, int ox, int oy, int cx, int
     int xpos = m_noItemHMargin;
     int ypos = m_noItemVMargin + p->fontMetrics().height();
 
-    for( QStringList::Iterator str = lines.begin(); str != lines.end(); str++ ) {
+    QStringList::Iterator end ( lines.end() );
+    for( QStringList::Iterator str = lines.begin(); str != end; ++str ) {
       p->drawText( xpos, ypos, *str );
       ypos += p->fontMetrics().lineSpacing();
     }
@@ -844,8 +888,12 @@ void K3bListView::slotEditorLineEditReturnPressed()
     // TODO: add config for this
     if( K3bListViewItem* nextItem = dynamic_cast<K3bListViewItem*>( m_currentEditItem->nextSibling() ) )
       editItem( nextItem, currentEditColumn() );
-    else
+    else {
       hideEditor();
+
+      // keep the focus here
+      viewport()->setFocus();
+    }
   }
 }
 
@@ -949,8 +997,11 @@ void K3bListView::slotEditorButtonClicked()
 }
 
 
-bool K3bListView::renameItem( K3bListViewItem*, int, const QString& )
+bool K3bListView::renameItem( K3bListViewItem* item, int col, const QString& text )
 {
+  Q_UNUSED(item);
+  Q_UNUSED(col);
+  Q_UNUSED(text);
   return true;
 }
 
@@ -961,22 +1012,14 @@ void K3bListView::slotEditorButtonClicked( K3bListViewItem* item, int col )
 }
 
 
-void K3bListView::setValidator( QValidator* v )
-{
-  m_validator = v;
-  if( m_editorLineEdit ) 
-    m_editorLineEdit->setValidator( v );
-  if( m_editorComboBox )
-    m_editorComboBox->setValidator( v );
-}
-
-
 bool K3bListView::eventFilter( QObject* o, QEvent* e )
 {
   if( e->type() == QEvent::KeyPress ) { 
      QKeyEvent* ke = static_cast<QKeyEvent*>(e);
      if( ke->key() == Key_Tab ) {
-       if( o == m_editorLineEdit || o == m_editorMsfEdit || o == m_editorSpinBox ) {
+       if( o == m_editorLineEdit || 
+	   o == d->msfEditLineEdit || 
+	   o == d->spinBoxLineEdit ) {
 	 K3bListViewItem* lastEditItem = m_currentEditItem;
 
 	 doRename();
@@ -988,54 +1031,121 @@ bool K3bListView::eventFilter( QObject* o, QEvent* e )
 	     ++col;
 	   if( col < columns() )
 	     editItem( lastEditItem, col );
-	   else if( K3bListViewItem* nextItem = 
-		    dynamic_cast<K3bListViewItem*>( lastEditItem->nextSibling() ) ) {
-	     // edit first column
-	     col = 0;
-	     while( col < columns() && nextItem->editorType( col ) == K3bListViewItem::NONE )
-	       ++col;
-	     editItem( nextItem, col );
-	   }
-	   else
+	   else {
 	     hideEditor();
+
+	     // keep the focus here
+	     viewport()->setFocus();
+
+	     // search for the next editable item
+	     while( K3bListViewItem* nextItem = 
+		    dynamic_cast<K3bListViewItem*>( lastEditItem->nextSibling() ) ) {
+	       // edit first column
+	       col = 0;
+	       while( col < columns() && nextItem->editorType( col ) == K3bListViewItem::NONE )
+		 ++col;
+	       if( col < columns() ) {
+		 editItem( nextItem, col );
+		 break;
+	       }
+	       
+	       lastEditItem = nextItem;
+	     }
+	   }
 	 }
 
 	 return true;
        }
      }
      if( ke->key() == Key_Return ) {
-       if( o == m_editorLineEdit || o == m_editorMsfEdit || o == m_editorSpinBox ) {
+       if( o == m_editorLineEdit || 
+	   o == d->msfEditLineEdit || 
+	   o == d->spinBoxLineEdit ) {
 	 K3bListViewItem* lastEditItem = m_currentEditItem;
 	 doRename();
 
 	 if( K3bListViewItem* nextItem = 
 	     dynamic_cast<K3bListViewItem*>( lastEditItem->nextSibling() ) )
 	   editItem( nextItem, currentEditColumn() );
-	 else
+	 else {
 	   hideEditor();
 
+	   // keep the focus here
+	   viewport()->setFocus();
+	 }
+
 	 return true;
        }
      }
      else if( ke->key() == Key_Escape ) {
-       if( o == m_editorLineEdit || o == m_editorSpinBox || o == m_editorMsfEdit )
+       if( o == m_editorLineEdit || 
+	   o == d->msfEditLineEdit || 
+	   o == d->spinBoxLineEdit ) {
 	 hideEditor();
 
-       return true;
+	 // keep the focus here
+	 viewport()->setFocus();
+
+	 return true;
+       }
      }
   }
-  else if( e->type() == QEvent::FocusOut ) {
-    if( o == m_editorSpinBox ||
-	o == m_editorMsfEdit ||
-	o == m_editorLineEdit ) {
-      doRename();
-      hideEditor();
+
+  else if( e->type() == QEvent::MouseButtonPress && o == viewport() ) {
+
+    // first let's grab the focus
+    viewport()->setFocus();
+
+    QMouseEvent* me = static_cast<QMouseEvent*>( e );
+    QListViewItem* item = itemAt( me->pos() );
+    int col = header()->sectionAt( me->pos().x() );
+    if( K3bCheckListViewItem* ci = dynamic_cast<K3bCheckListViewItem*>( item ) ) {
+      if( col == 0 ) {
+	// FIXME: improve this click area!
+	ci->setChecked( !ci->isChecked() );
+	return true;
+      }
     }
-    else if( o == m_editorComboBox ) {
-      // make sure we did not lose the focus to one of the combobox children
-      if( ( !m_editorComboBox->listBox() || !m_editorComboBox->listBox()->hasFocus() ) &&
-	  ( !m_editorComboBox->lineEdit() || !m_editorComboBox->lineEdit()->hasFocus() ) )
+
+    if( me->button() == QMouseEvent::LeftButton ) {
+      if( item != m_currentEditItem || m_currentEditColumn != col ) {
+	doRename();
+	if( K3bListViewItem* k3bItem = dynamic_cast<K3bListViewItem*>(item) ) {
+	  if( me->pos().x() > item->depth()*treeStepSize() && 
+	      item->isEnabled() && 
+	      (m_lastClickedItem == item || !m_doubleClickForEdit) )
+	    showEditor( k3bItem, col );
+	  else {
+	    hideEditor();
+
+	    // keep the focus here
+	    viewport()->setFocus();
+	  }
+	}
+	else {
+	  hideEditor();
+
+	  // keep the focus here
+	  viewport()->setFocus();
+	}
+
+	// do not count clicks in the item tree for editing
+	if( item && me->pos().x() > item->depth()*treeStepSize() )
+	  m_lastClickedItem = item;
+      }
+    }
+  }
+
+  else if( e->type() == QEvent::FocusOut ) {
+    if( o == m_editorLineEdit || 
+	o == d->msfEditLineEdit || 
+	o == d->spinBoxLineEdit ||
+	o == m_editorComboBox ) {
+      // make sure we did not lose the focus to one of the edit widgets' children
+      if( !qApp->focusWidget() || qApp->focusWidget()->parentWidget() != o ) {
+	doRename();
 	hideEditor();
+      }
     }
   }
 
@@ -1105,4 +1215,75 @@ QListViewItem* K3bListView::parentItem( QListViewItem* item )
     return K3bListView::parentItem( item->itemAbove() );
 }
 
+
+KPixmap K3bListView::createDragPixmap( const QPtrList<QListViewItem>& items )
+{
+  //
+  // Create drag pixmap.
+  // If there are too many items fade the pixmap using the mask
+  // always fade invisible items
+  //
+  int width = header()->width();
+  int height = 0;
+  for( QPtrListIterator<QListViewItem> it( items ); *it; ++it ) {
+    QRect r = itemRect( *it );
+
+    if( r.isValid() ) {
+      height += ( *it )->height();
+    }
+  }
+
+  // now we should have a range top->bottom which includes all visible items
+  
+  // there are two situations in which we fade the pixmap on the top or the bottom:
+  // 1. there are invisible items above (below) the visible
+  // 2. the range is way too big
+
+  // FIXME: how do we determine if there are invisible items outside our range?
+
+  KPixmap pix;
+  pix.resize( width, height );
+  pix.fill( Qt::white );
+  //  QBitmap mask( width, bottom-top );
+
+  // now paint all the visible items into the pixmap
+  // FIXME: only paint the visible items
+  QPainter p( &pix );
+  for( QListViewItemIterator it( this ); *it; ++it ) {
+    QListViewItem* item = *it;
+
+    // FIXME: items on other than the top level have a smaller first column
+    //        the same goes for all items if root is decorated
+    bool alreadyDrawing = false;
+    QRect r = itemRect( item );
+    if( r.isValid() ) {
+      if( items.containsRef( item ) ) {
+	// paint all columns
+	int x = 0;
+	for( int i = 0; i < columns(); ++i ) {
+	  item->paintCell( &p, colorGroup(), i, columnWidth( i ), columnAlignment( i ) );
+	  p.translate( columnWidth( i ), 0 );
+	  x += columnWidth( i );
+	}
+
+	p.translate( -x, item->height() );
+
+	alreadyDrawing = true;
+      }
+      else if( alreadyDrawing )
+	p.translate( 0, item->height() );
+
+      if( p.worldMatrix().dy() >= pix.height() )
+	break;
+    }
+  }
+
+  // make it a little lighter
+  KPixmapEffect::fade( pix, 0.3, Qt::white );
+
+  // FIXME: fade the pixmap at the right side if the items are longer than width
+
+  return pix;
+}
+
 #include "k3blistview.moc"
