@@ -107,15 +107,20 @@ QString K3bMadDecoder::metaInfo( MetaDataField f )
 #ifdef HAVE_TAGLIB
   TagLib::MPEG::File file( QFile::encodeName( filename() ).data() );
 
-  switch( f ) {
-  case META_TITLE:
-    return TStringToQString( file.tag()->title() );
-  case META_ARTIST:
-    return TStringToQString( file.tag()->artist() );
-  case META_COMMENT:
-    return TStringToQString( file.tag()->comment() );
-  default:
-    return QString::null;
+  if ( file.tag() ) {
+      switch( f ) {
+      case META_TITLE:
+          return TStringToQString( file.tag()->title() );
+      case META_ARTIST:
+          return TStringToQString( file.tag()->artist() );
+      case META_COMMENT:
+          return TStringToQString( file.tag()->comment() );
+      default:
+          return QString::null;
+      }
+  }
+  else {
+      return QString::null;
   }
 
 #else
@@ -144,7 +149,7 @@ bool K3bMadDecoder::initDecoderInternal()
   cleanup();
 
   d->bOutputFinished = false;
-    
+
   if( !d->handle->open( filename() ) )
     return false;
 
@@ -177,11 +182,11 @@ unsigned long K3bMadDecoder::countFrames()
     }
     else if( d->handle->madFrame->header.bitrate != d->firstHeader.bitrate )
       d->vbr = true;
-    
+
     //
     // position in stream: postion in file minus the not yet used buffer
     //
-    unsigned long long seekPos = d->handle->inputPos() - 
+    unsigned long long seekPos = d->handle->inputPos() -
       (d->handle->madStream->bufend - d->handle->madStream->this_frame + 1);
 
     // save the number of bytes to be read to decode i-1 frames at position i
@@ -191,7 +196,7 @@ unsigned long K3bMadDecoder::countFrames()
 
   if( !d->handle->inputError() && !error ) {
     // we need the length of the track to be multiple of frames (1/75 second)
-    float seconds = (float)d->handle->madTimer->seconds + 
+    float seconds = (float)d->handle->madTimer->seconds +
       (float)d->handle->madTimer->fraction/(float)MAD_TIMER_RESOLUTION;
     frames = (unsigned long)ceil(seconds * 75.0);
     kdDebug() << "(K3bMadDecoder) length of track " << seconds << endl;
@@ -223,12 +228,12 @@ int K3bMadDecoder::decodeInternal( char* _data, int maxLen )
       bOutputBufferFull = true;
     }
     else if( d->handle->decodeNextFrame() ) {
-      // 
+      //
       // Once decoded the frame is synthesized to PCM samples. No errors
       // are reported by mad_synth_frame();
       //
       mad_synth_frame( d->handle->madSynth, d->handle->madFrame );
-      
+
       // this fills the output buffer
       if( !createPcmSamples( d->handle->madSynth ) ) {
 	return -1;
@@ -280,17 +285,17 @@ bool K3bMadDecoder::createPcmSamples( mad_synth* synth )
     unsigned short sample = linearRound( synth->pcm.samples[0][i] );
     *(d->outputPointer++) = (sample >> 8) & 0xff;
     *(d->outputPointer++) = sample & 0xff;
-    
+
     /* Right channel. If the decoded stream is monophonic then
      * the right output channel is the same as the left one.
      */
     if( synth->pcm.channels == 2 )
       sample = linearRound( synth->pcm.samples[1][i] );
-      
+
     *(d->outputPointer++) = (sample >> 8) & 0xff;
     *(d->outputPointer++) = sample & 0xff;
   } // pcm conversion
-  
+
   return true;
 }
 
@@ -304,7 +309,7 @@ void K3bMadDecoder::cleanup()
 bool K3bMadDecoder::seekInternal( const K3b::Msf& pos )
 {
   //
-  // we need to reset the complete mad stuff 
+  // we need to reset the complete mad stuff
   //
   if( !initDecoderInternal() )
     return false;
@@ -313,7 +318,7 @@ bool K3bMadDecoder::seekInternal( const K3b::Msf& pos )
   // search a position
   // This is all hacking, I don't really know what I am doing here... ;)
   //
-  double mp3FrameSecs = static_cast<double>(d->firstHeader.duration.seconds) 
+  double mp3FrameSecs = static_cast<double>(d->firstHeader.duration.seconds)
     + static_cast<double>(d->firstHeader.duration.fraction) / static_cast<double>(MAD_TIMER_RESOLUTION);
 
   double posSecs = static_cast<double>(pos.totalFrames()) / 75.0;
@@ -330,7 +335,7 @@ bool K3bMadDecoder::seekInternal( const K3b::Msf& pos )
   // seek in the input file behind the already decoded data
   d->handle->inputSeek( d->seekPositions[frame] );
 
-  kdDebug() << "(K3bMadDecoder) Seeking to frame " << frame << " with " 
+  kdDebug() << "(K3bMadDecoder) Seeking to frame " << frame << " with "
 	    << frameReservoirProtect << " reservoir frames." << endl;
 
   // decode some frames ignoring MAD_ERROR_BADDATAPTR errors
@@ -347,7 +352,7 @@ bool K3bMadDecoder::seekInternal( const K3b::Msf& pos )
 	  continue;
 	}
 	else {
-	  kdDebug() << "(K3bMadDecoder) Seeking: ignoring (" 
+	  kdDebug() << "(K3bMadDecoder) Seeking: ignoring ("
 		    << mad_stream_errorstr(d->handle->madStream) << ")" << endl;
 	}
       }
@@ -381,7 +386,7 @@ QString K3bMadDecoder::fileType() const
 
 QStringList K3bMadDecoder::supportedTechnicalInfos() const
 {
-  return QStringList::split( ";", 
+  return QStringList::split( ";",
 			     i18n("Channels") + ";" +
 			     i18n("Sampling Rate") + ";" +
 			     i18n("Bitrate") + ";" +
@@ -463,7 +468,7 @@ K3bMadDecoderFactory::~K3bMadDecoderFactory()
 }
 
 
-K3bAudioDecoder* K3bMadDecoderFactory::createDecoder( QObject* parent, 
+K3bAudioDecoder* K3bMadDecoderFactory::createDecoder( QObject* parent,
 						      const char* name ) const
 {
   return new K3bMadDecoder( parent, name );
@@ -518,7 +523,7 @@ bool K3bMadDecoderFactory::canDecode( const KURL& url )
 	// only support layer III for now since otherwise some wave files
 	// are taken for layer I
 	if( ++cnt >= 5 ) {
-	  kdDebug() << "(K3bMadDecoder) valid mpeg 1 layer " << layer 
+	  kdDebug() << "(K3bMadDecoder) valid mpeg 1 layer " << layer
 		    << " file with " << c << " channels and a samplerate of "
 		    << s << endl;
 	  return ( layer == MAD_LAYER_III );
