@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bwavedecoder.cpp 489631 2005-12-19 10:58:06Z trueg $
+ * $Id: k3bwavedecoder.cpp 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -224,7 +224,7 @@ int K3bWaveDecoder::decodeInternal( char* _data, int maxLen )
       d->alreadyRead += read;
 
       if( read % 2 > 0 ) {
-	kdDebug() << "(K3bWaveDecoder) data length is not a multible of 2! Cutting data." << endl;
+	kdDebug() << "(K3bWaveDecoder) data length is not a multiple of 2! Cutting data." << endl;
 	read -= 1;
       }
 
@@ -274,7 +274,7 @@ bool K3bWaveDecoder::analyseFileInternal( K3b::Msf& frames, int& samplerate, int
       size *= 2;
 
     //
-    // we pad to a multible of 2352 bytes 
+    // we pad to a multiple of 2352 bytes 
     // (the actual padding of zero data will be done by the K3bAudioDecoder class)
     //
     if( (size%2352) > 0 )
