@@ -1,10 +1,10 @@
 /*
  *
- * $Id: k3bfiletreeview.h 366987 2004-11-28 20:49:22Z trueg $
+ * $Id: k3bfiletreeview.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -51,32 +51,24 @@ class K3bDeviceBranch : public KFileTreeBranch
    */
   void showBlockDeviceName( bool b );
 
- signals:
-  /**
-   * mountPoint is empty if not successful
-   */
-  void mountFinished( K3bDeviceBranch*, const QString& mountPoint );
-  void unmountFinished( K3bDeviceBranch*, bool success );
-
  public slots:
-  void mount();
-  void unmount();
+  void setCurrent( bool );
 
-//  bool populate( const KURL& url, KFileTreeViewItem* v );
+  bool populate( const KURL& url,  KFileTreeViewItem *currItem );
 
  private slots:
-  void slotMountFinished( KIO::Job* );
-  void slotUnmountFinished( KIO::Job* );
+  void slotMediumChanged( K3bDevice::Device* );
 
  private:
+  void updateLabel();
+
   K3bDevice::Device* m_device;
+  bool m_showBlockDeviceName;
 };
 
 
 class K3bFileTreeBranch : public KFileTreeBranch
 {
-  Q_OBJECT
-
  public:
   K3bFileTreeBranch( KFileTreeView*,
 		     const KURL& url,
@@ -90,10 +82,21 @@ class K3bFileTreeBranch : public KFileTreeBranch
 class K3bDeviceBranchViewItem : public KFileTreeViewItem
 {
  public:
-  K3bDeviceBranchViewItem( KFileTreeViewItem*, KFileItem*, KFileTreeBranch* );
-  K3bDeviceBranchViewItem( KFileTreeView *, KFileItem*, KFileTreeBranch* );
+  K3bDeviceBranchViewItem( KFileTreeViewItem*, K3bDevice::Device*, K3bDeviceBranch* );
+  K3bDeviceBranchViewItem( KFileTreeView*, K3bDevice::Device*, K3bDeviceBranch* );
 
   QString key( int column, bool ascending ) const;
+
+  void setCurrent( bool );
+
+  void paintCell( QPainter* p, const QColorGroup& cg, int col, int width, int align );
+
+  int widthHint() const;
+
+ private:
+  bool m_bCurrent;
+
+  K3bDevice::Device* m_device;
 };
 
 
@@ -133,7 +136,6 @@ class K3bFileTreeView : public KFileTreeView
    * returnes an empty url if no url is selected
    */
   KURL selectedUrl() const;
-  void setSelectedDevice(K3bDevice::Device* dev);
 
  public slots:
   /**
@@ -143,6 +145,18 @@ class K3bFileTreeView : public KFileTreeView
   void addCdDeviceBranches( K3bDevice::DeviceManager* );
   void addDeviceBranch( K3bDevice::Device* dev );
 
+  /**
+   * Make dev the current device. This does not mean that the device entry
+   * will be highlighted but marked otherwise since this means that it is the
+   * current device in the application and not the treeview.
+   */
+  void setCurrentDevice( K3bDevice::Device* dev );
+
+  /**
+   * his will highlight the device and also make it the current device.
+   */
+  void setSelectedDevice( K3bDevice::Device* dev );
+
   void followUrl( const KURL& url );
   void setTreeDirOnlyMode( bool b );
   void enablePopupMenu( bool b ) { m_menuEnabled = b; }
@@ -152,6 +166,8 @@ class K3bFileTreeView : public KFileTreeView
    */
   virtual void clear();
 
+  void updateMinimumWidth();
+
  signals:
   void urlExecuted( const KURL& url );
   void deviceExecuted( K3bDevice::Device* dev );
@@ -160,9 +176,6 @@ class K3bFileTreeView : public KFileTreeView
   void contextMenu( K3bDevice::Device*, const QPoint& );
   /** only gets emitted if the menu is disabled */
   void contextMenu( const KURL& url, const QPoint& );
-
-  void mountFinished( K3bDeviceBranch*, const QString& mountPoint );
-  void unmountFinished( K3bDeviceBranch*, bool success );
   
  private slots:
   void slotItemExecuted( QListViewItem* item );
