@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3binterface.cpp 396050 2005-03-09 11:44:27Z trueg $
+ * $Id: k3binterface.cpp 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,15 +23,17 @@
 #include "k3bcore.h"
 #include "k3b.h"
 
+#include <k3bglobals.h>
+
 #include <dcopclient.h>
 #include <qptrlist.h>
 #include <qtimer.h>
 
 
 
-K3bInterface::K3bInterface( K3bMainWindow* w )
+K3bInterface::K3bInterface()
   : DCOPObject( "K3bInterface" ),
-    m_main( w )
+    m_main( 0 )
 {
 }
 
@@ -126,6 +128,18 @@ void K3bInterface::addUrl( const KURL& url )
 }
 
 
+void K3bInterface::copyCd( const KURL& dev )
+{
+  m_main->cdCopy( K3b::urlToDevice( dev ) );
+}
+
+
+void K3bInterface::copyDvd( const KURL& dev )
+{
+  m_main->dvdCopy( K3b::urlToDevice( dev ) );
+}
+
+
 void K3bInterface::copyCd()
 {
   // HACK since we want this method to return immediately
@@ -170,3 +184,9 @@ bool K3bInterface::blocked() const
 {
   return k3bcore->jobsRunning();
 }
+
+
+void K3bInterface::cddaRip( const KURL& dev )
+{
+  m_main->cddaRip( K3b::urlToDevice( dev ) );
+}
