@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bexternalbinwidget.h 281500 2004-01-21 10:20:23Z trueg $
+ * $Id: k3bexternalbinwidget.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,15 +21,13 @@
 #include <qwidget.h>
 #include <qptrlist.h>
 
-#include <klistview.h>
+#include <k3blistview.h>
 
 
 class K3bExternalBinManager;
 class QPushButton;
-class KListView;
 class QTabWidget;
 class KEditListBox;
-class QListViewItem;
 class K3bExternalProgram;
 class K3bExternalBin;
 
@@ -59,8 +57,8 @@ class K3bExternalBinWidget : public QWidget
   K3bExternalBinManager* m_manager;
 
   QTabWidget* m_mainTabWidget;
-  KListView* m_programView;
-  KListView* m_parameterView;
+  K3bListView* m_programView;
+  K3bListView* m_parameterView;
   KEditListBox* m_searchPathBox;
 
   QPushButton* m_defaultButton;
@@ -70,23 +68,20 @@ class K3bExternalBinWidget : public QWidget
 };
 
 
-class K3bExternalBinWidget::K3bExternalProgramViewItem : public KListViewItem
+class K3bExternalBinWidget::K3bExternalProgramViewItem : public K3bListViewItem
 {
  public:
   K3bExternalProgramViewItem( K3bExternalProgram* p, QListView* parent );
   
   K3bExternalProgram* program() const { return m_program; }
   
- protected:
-  void paintCell( QPainter* p, const QColorGroup& cg, int column, int width, int align );
-  
  private:
   K3bExternalProgram* m_program;
 };
 
 
 
-class K3bExternalBinWidget::K3bExternalBinViewItem : public KListViewItem
+class K3bExternalBinWidget::K3bExternalBinViewItem : public K3bListViewItem
 {
  public:
   K3bExternalBinViewItem( K3bExternalBin* bin, K3bExternalProgramViewItem* parent );
