@@ -1,10 +1,10 @@
 /* 
  *
- * $Id: k3bthemeoptiontab.h,v 1.2 2004/01/21 10:20:13 trueg Exp $
+ * $Id: k3bthemeoptiontab.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,8 @@ class K3bThemeOptionTab : public base_K3bThemeOptionTab
 
  private slots:
   void selectionChanged();
+  void slotInstallTheme();
+  void slotRemoveTheme();
 
  private:
   class Private;
